@@ -3,7 +3,7 @@ import sys
 import unittest
 import warnings
 
-from typing import Iterable, Optional, Union
+from typing import Iterable, Optional, Type, Union
 from unittest.mock import patch
 
 import pytest
@@ -13,8 +13,20 @@ from faker import Faker
 
 @pytest.mark.parametrize("object_type", (None, bool, str, float, int, tuple, set, list, Iterable, dict))
 def test_pyobject(
-    object_type: Optional[Union[bool, str, float, int, tuple, set, list, Iterable, dict]],
-):
+    object_type: Optional[
+        Union[
+            Type[bool],
+            Type[str],
+            Type[float],
+            Type[int],
+            Type[tuple],
+            Type[set],
+            Type[list],
+            Type[Iterable],
+            Type[dict],
+        ]
+    ],
+) -> None:
     random_object = Faker().pyobject(object_type=object_type)
     if object_type is None:
         assert random_object is None
@@ -84,6 +96,36 @@ def test_pyfloat_right_or_left_digit_overflow():
             assert str(abs(result)) == "1.12345678901234"
 
 
+@pytest.mark.skipif(sys.version_info < (3, 10), reason="Only relevant for Python 3.10 and later.")
+@pytest.mark.parametrize(
+    ("min_value", "max_value"),
+    [
+        (1.5, None),
+        (-1.5, None),
+        (None, -1.5),
+        (None, 1.5),
+        (-1.5, 1.5),
+    ],
+)
+@pytest.mark.parametrize(("left_digits"), [None, 5])
+@pytest.mark.parametrize(("right_digits"), [None, 5])
+@pytest.mark.filterwarnings(
+    # Convert the warning to an error for this test
+    r"error:non-integer arguments to randrange\(\):DeprecationWarning"
+)
+def test_float_min_and_max_value_does_not_crash(
+    left_digits: Optional[int],
+    right_digits: Optional[int],
+    min_value: Optional[float],
+    max_value: Optional[float],
+):
+    """
+    Float arguments to randrange are deprecated from Python 3.10. This is a regression
+    test to check that `pydecimal` does not cause a crash on any code path.
+    """
+    Faker().pydecimal(left_digits, right_digits, min_value=min_value, max_value=max_value)
+
+
 class TestPyint(unittest.TestCase):
     def setUp(self):
         self.fake = Faker()
@@ -162,7 +204,7 @@ class TestPyfloat(unittest.TestCase):
         self.assertGreaterEqual(result, 0)
 
     def test_max_value(self):
-        max_values = (0, 10, -1000, 1000, 999999, 100000000000001.0, -1000000000000001.0)
+        max_values = (0, 10, -1000, 1000, 999999)
 
         for max_value in max_values:
             result = self.fake.pyfloat(max_value=max_value)
@@ -210,33 +252,6 @@ class TestPyfloat(unittest.TestCase):
             self.assertLessEqual(result, 200.321)
             self.assertGreaterEqual(result, 100.123)
 
-    def test_max_none_and_min_value_with_decimals(self):
-        """
-        Combining the max_value and min_value keyword arguments with
-        positive value for min and None for max produces numbers with
-        left and right digits specified produced numbers greater than
-        the supplied min_value.
-        """
-        for _ in range(1000):
-            result = self.fake.pyfloat(min_value=99884.7, max_value=None, left_digits=5, right_digits=2)
-            self.assertGreaterEqual(result, 99884.7)
-            assert len(str(result).strip("-").split(".")[0]) == 5
-            assert len(str(result).strip("-").split(".")[1]) <= 2
-
-    def test_min_none_and_max_value_with_decimals(self):
-        """
-        Combining the max_value and min_value keyword arguments with
-        positive value for max and None for min produces numbers with
-        left and right digits specified produced numbers greater than
-        the supplied min_value.
-        """
-        for _ in range(1000):
-            result = self.fake.pyfloat(min_value=None, max_value=11000.3, left_digits=5, right_digits=2)
-            self.assertLessEqual(result, 11000.3)
-            assert len(str(result).strip("-").split(".")[0]) == 5
-            assert len(str(result).strip("-").split(".")[1]) <= 2
-
-
     def test_max_and_min_value_negative(self):
         """
         Combining the max_value and min_value keyword arguments with
@@ -296,6 +311,34 @@ class TestPyfloat(unittest.TestCase):
         self.fake.pyfloat(min_value=2.3, max_value=2.5)
 
 
+class TestPyDict(unittest.TestCase):
+    def setUp(self):
+        self.fake = Faker()
+        Faker.seed(0)
+
+    def test_pydict_with_default_nb_elements(self):
+        result = self.fake.pydict()
+
+        self.assertEqual(len(result), 10)
+
+    def test_pydict_with_valid_number_of_nb_elements(self):
+        result = self.fake.pydict(nb_elements=5)
+
+        self.assertEqual(len(result), 5)
+
+    def test_pydict_with_invalid_number_of_nb_elements(self):
+        nb_elements = 10000
+
+        words_list_count = len(self.fake.get_words_list())
+        warning_msg = (
+            f"Number of nb_elements is greater than the number of words in the list."
+            f" {words_list_count} words will be used."
+        )
+        with pytest.warns(RuntimeWarning, match=warning_msg):
+            result = self.fake.pydict(nb_elements=nb_elements)
+            self.assertEqual(len(result), words_list_count)
+
+
 class TestPydecimal(unittest.TestCase):
     def setUp(self):
         self.fake = Faker()
@@ -520,7 +563,7 @@ class TestPystrFormat(unittest.TestCase):
         Faker.seed(0)
 
     def test_formatter_invocation(self):
-        with patch.object(self.fake["en_US"], "foo") as mock_foo:
+        with patch.object(self.fake["en_US"].factories[0], "foo") as mock_foo:
             with patch("faker.providers.BaseProvider.bothify", wraps=self.fake.bothify) as mock_bothify:
                 mock_foo.return_value = "barbar"
                 value = self.fake.pystr_format("{{foo}}?#?{{foo}}?#?{{foo}}", letters="abcde")
